Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(250)

Unified Diff: webkit/media/crypto/key_systems.h

Issue 15028015: Conditionally build support for Pepper-based CDMs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Use AppendAscii() where possible. Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/widevine/cdm/widevine_cdm_common.h ('k') | webkit/media/crypto/key_systems.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/media/crypto/key_systems.h
diff --git a/webkit/media/crypto/key_systems.h b/webkit/media/crypto/key_systems.h
index 41e567258f2cd446074904a659142403fedda233..41412a4830a946cc880b0f472da1dad05ad1f0a7 100644
--- a/webkit/media/crypto/key_systems.h
+++ b/webkit/media/crypto/key_systems.h
@@ -34,9 +34,11 @@ std::string KeySystemNameForUMA(const WebKit::WebString& key_system);
// Returns whether AesDecryptor can be used for the given |key_system|.
bool CanUseAesDecryptor(const std::string& key_system);
-// Returns the plugin type given a |key_system|.
-// Returns an empty string if no plugin type is found for |key_system|.
-std::string GetPluginType(const std::string& key_system);
+#if defined(ENABLE_PEPPER_CDMS)
+// Returns the Pepper MIME type for |key_system|.
+// Returns an empty string if |key_system| is unknown or not Pepper-based.
+std::string GetPepperType(const std::string& key_system);
+#endif
} // namespace webkit_media
« no previous file with comments | « third_party/widevine/cdm/widevine_cdm_common.h ('k') | webkit/media/crypto/key_systems.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698